@@ -1,7 +1,7 @@
 package App::DiffTarballs;
 
-our $DATE = '2017-08-06'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-08-07'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -54,6 +54,7 @@ $SPEC{diff_tarballs} = {
 sub diff_tarballs {
     require Cwd;
     require File::Temp;
+    require ShellQuote::Any::Tiny;
 
     my %args = @_;
 
@@ -94,7 +95,13 @@ sub diff_tarballs {
 
     rename "$dir1/$glob1[0]", "$dir2/$name1";
 
-    system({log=>1}, "diff", "-ruN", $name1, $name2);
+    my $diff_cmd = $ENV{DIFF} // "diff -ruN";
+    system({log=>1, shell=>1}, join(
+        " ",
+        $diff_cmd,
+        ShellQuote::Any::Tiny::shell_quote($name1),
+        ShellQuote::Any::Tiny::shell_quote($name2),
+    ));
 
     unless ($cleanup) {
         log_info("Not cleaning up temporary directory %s", $dir2);
@@ -118,7 +125,7 @@ App::DiffTarballs - Diff contents of two tarballs
 
 =head1 VERSION
 
-This document describes version 0.002 of App::DiffTarballs (from Perl distribution App-DiffTarballs), released on 2017-08-06.
+This document describes version 0.003 of App::DiffTarballs (from Perl distribution App-DiffTarballs), released on 2017-08-07.
 
 =head1 SYNOPSIS
 
@@ -178,6 +185,12 @@ Return value:  (any)
 If set to true, will cause temporary directories to not being cleaned up after
 the program is done.
 
+=head2 DIFF => str
+
+Set diff command to use. Defaults to C<diff -ruN>. For example, you can set it
+to C<diff --color -ruN> (C<--color> requires GNU diff 3.4 or later), or
+C<colordiff -ruN>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-DiffTarballs>.
